@@ -114,7 +114,7 @@ def translate():
         content.replace('\n', ' ')
         translator = Dict()
         ret = translator.dictionary(content)
-        print(ret['trans_result']['data'][0]['dst'])
+        print(ret if ret else 'Translate Failed!')
     else:
         print("No content in your clipboard or command parameters!")
 
@@ -157,7 +157,8 @@ def weather():
             from QuickStart_Rhy.API.Dict import Dict
             translator = Dict()
             try:
-                print('地区：' + translator.dictionary(simple[0].split('：')[-1])['trans_result']['data'][0]['dst'])
+                trans_loaction = translator.dictionary(simple[0].split('：')[-1])
+                print('地区：' + trans_loaction if trans_loaction else simple[0].split('：')[-1])
             except:
                 print('地区：' + simple[0].split('：')[-1])
         simple = simple[2:7]
